import React, { useEffect, useState } from "react";
import { Button, Card, Switch, Table } from "antd";
import { ProTable } from "@ant-design/pro-components";
import { getTaMemberCard } from "@/services/taMemberCard";
import { getTaPackage } from "@/services/taPackage";
import { getTaOrder } from "@/services/taOrder";
import { queryTable, queryDict } from "@/utils/request";
import moment from "moment";
import MemberOrderModal from "./MemberOrderModal";

const PackageNameList = queryDict(getTaPackage, { labelKey: "packageName", valueKey: "packageId" });

export default (props) => {
  const { memberId, setMemberCardId } = props;
  const actionRef = React.useRef();

  const TaMemberCardList = queryTable(() =>
    getTaMemberCard({ memberId: memberId })
  );

  const columns = [
    {
      title: "套餐名称",
      dataIndex: "packageId",
      valueType: 'select',
      request: PackageNameList,
      ellipsis: true,
    },
    {
      title: "开卡人姓名",
      dataIndex: "memberName",
    },
    {
      title: "手机号",
      dataIndex: "memberPhone",
    },
    {
      title: "总次数",
      dataIndex: "totalAmount",
    },
    {
      title: "剩余次数",
      dataIndex: "leftAmount",
    },
    {
      title: "开卡日期",
      dataIndex: "bizDate",
      render: (_, record) => {
        const bDate = record.bizDate;

        return bDate ? moment(bDate).format("YYYY-MM-DD HH:mm:ss") : "-";
      },
    },
    {
      title: "总时长",
      dataIndex: "totalTime",
    },
    {
      title: "截止日期",
      dataIndex: "expireTime",
      render: (_, record) => {
        const eTime = record.expireTime;
        return eTime ? moment(eTime).format("YYYY-MM-DD HH:mm:ss") : "-";
      },
    },
    {
      title: "操作",
      valueType: "option",
      key: "option",
      ellipsis: true,
      render: (_, record) => [
        <Button
          style={{ padding: 0 }}
          type="link"
          key={1}
          onClick={() => onClick(record)}
        >
          消费记录
        </Button>,
      ],
    },
  ];

  const onClick = (val) => {
    setMemberCardId(val?.cardId);
  };

  return (
    <>
      <ProTable
        actionRef={actionRef}
        rowKey="cardId"
        columns={columns}
        options={false}
        search={false}
        request={TaMemberCardList}
      />
    </>
  );
};
