import React, { useRef } from "react";
import List from "@/components/Page/List";
import { getTaOrder } from "@/services/taOrder";
import { getTaMemberCard } from "@/services/taMemberCard";
import moment from "moment";
import Page from '@/components/Page';
import { ProTable } from '@ant-design/pro-components';
import { queryTable, queryDict } from "@/utils/request";
import { getSysUser } from "@/services/sysUser";
import {
  BILL_CONSUME,
  BILL_REFUND,
  BILL_RECHARGE,
  BILL_WITHDRAW,
} from "@/utils/biz";

const TaOrderList = queryTable(getTaOrder);

const TaSysUserList = queryDict(getSysUser, { labelKey: "userName", valueKey: "userId" });
export default (props) => {
  const actionRef = useRef();

  const columns = [
    {
      title: "会员名称",
      dataIndex: "memberName",
    },
    {
      title: '套餐名称',
      dataIndex: "packageName",
      search: false
    },
    {
      title: "消费类型",
      dataIndex: "billType",
      valueType: "select",
      valueEnum: {
        'consume': '消费',
        'refund': '退款',
        'recharge': '充值-开卡',
        'withdraw': '提现',
      }
    },
    {
      title: "总费用",
      dataIndex: "totalCharge",
      search: false
    },
    {
      title: "数量",
      dataIndex: "totalAmount",
      search: false
    },
    {
      title: "单价",
      dataIndex: "unitCharge",
      search: false
    },
    {
      title: "原始价格",
      dataIndex: "fullCharge",
      search: false
    },
    {
      title: "下单日期",
      dataIndex: "orderDate",
      render: (it) => (it == '-' ? '-' : moment(it).format("YYYY-MM-DD HH:mm:ss")),
      search: false
    },
    {
      title: "下单人名称",
      dataIndex: "personName",
      search: false
    },
    // {
    //   title: "是否退单",
    //   dataIndex: "isRefund",
    //   valueEnum: {
    //     1: '是',
    //     2: '否',
    //   },
    //   search: false
    // },
    {
      title: "操作时间",
      dataIndex: "createdAt",
      render: (it) => (it == '-' ? '-' : moment(it).format("YYYY-MM-DD HH:mm:ss")),
      search: false
    },
    {
      title: "操作人",
      dataIndex: "createdBy",
      valueType: "select",
      request: TaSysUserList,
      search: false,
    },
  ]

  return (
    <Page>
      <ProTable
        cardBordered
        rowKey="orderId"
        columns={columns}
        actionRef={actionRef}
        request={TaOrderList}
      />
    </Page>
  )
}